mmsharing/mmshengine/inc/musengtelephoneutils.h
branchRCL_3
changeset 21 33a5d2bbf6fc
parent 20 2d2c7d1515f7
child 22 73a1feb507fb
--- a/mmsharing/mmshengine/inc/musengtelephoneutils.h	Thu Jul 15 18:35:08 2010 +0300
+++ b/mmsharing/mmshengine/inc/musengtelephoneutils.h	Thu Aug 19 09:51:39 2010 +0300
@@ -70,11 +70,19 @@
         TBool AudioRoutingCanBeChanged() const;
         
         /**
 		* Checks if audio output is BT
 		* 
 		* @return ETrue if audio routing is BT
 		*/
-        TBool AudioOutputIsBT() const;
+        TBool IsAudioRoutingHeadset() const;
+        
+        /**
+		* Checks if audio routing is LoudSpeaker
+		* 
+		* @return ETrue if audio routing is LoudSpeaker and 
+		* currentMode != iAudioOutputAtStartup
+		*/
+        TBool IsAudioRoutingLoudSpeaker() const;
         
 		/**
    		* Changes the audio routing between loudspeaker and handset.
@@ -70,11 +70,19 @@
         
         /**
-		* Checks if audio output is BT
+		* Checks if audio routing is headset
 		* 
@@ -70,11 +70,19 @@
 		* 
-		* @return ETrue if audio routing is BT
+		* @return ETrue if audio routing is headset
 		*/